# Alg-service-api





## Install 

### Upgrade pip 

```shell

 python.exe -m pip install --upgrade pip

```

### Install basic package 

```commandline
pip install  grpcio grpcio-tools protobuf 

```


## Grpc tools 

cd $project 

```shell

.\tools\create_grpc_proto.cmd

```
